# Combining at top level

- [1. Property `Combining at top level > oneOf > diskDevice`](#oneOf_i0)
- [2. Property `Combining at top level > oneOf > diskUUID`](#oneOf_i1)
- [3. Property `Combining at top level > oneOf > nfs`](#oneOf_i2)
- [4. Property `Combining at top level > oneOf > tmpfs`](#oneOf_i3)

**Title:** Combining at top level

| Type                      | `combining`                                                               |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

**Description:** For the combine

## <a name="oneOf_i0"></a>1. Property `Combining at top level > oneOf > diskDevice`

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/diskDevice                                                  |
|                           |                                                                           |

## <a name="oneOf_i1"></a>2. Property `Combining at top level > oneOf > diskUUID`

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/diskUUID                                                    |
|                           |                                                                           |

## <a name="oneOf_i2"></a>3. Property `Combining at top level > oneOf > nfs`

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/nfs                                                         |
|                           |                                                                           |

## <a name="oneOf_i3"></a>4. Property `Combining at top level > oneOf > tmpfs`

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/tmpfs                                                       |
|                           |                                                                           |

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date